Method: Puppet::Parser::Collector#evaluate

Defined in:
lib/vendor/puppet/parser/collector.rb

#evaluateObject

Call the collection method, mark all of the returned objects as non-virtual, optionally applying parameter overrides. The collector can also delete himself from the compiler if there is no more resources to collect (valid only for resource fixed-set collector which get their resources from collect_resources and not from the catalog)



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/vendor/puppet/parser/collector.rb', line 11

def evaluate
  # Shortcut if we're not using storeconfigs and they're trying to collect
  # exported resources.
  if form == :exported and Puppet[:storeconfigs] != true
    Puppet.warning "Not collecting exported resources without storeconfigs"
    return false
  end

  if self.resources
    unless objects = collect_resources and ! objects.empty?
      return false
    end
  else
    method = "collect_#{@form.to_s}"
    objects = send(method).each do |obj|
      obj.virtual = false
    end
    return false if objects.empty?
  end

  # we have an override for the collected resources
  if @overrides and !objects.empty?
    # force the resource to be always child of any other resource
    overrides[:source].meta_def(:child_of?) do
      true
    end

    # tell the compiler we have some override for him unless we already
    # overrided those resources
    objects.each do |res|
      unless @collected.include?(res.ref)
        newres = Puppet::Parser::Resource.
          new(res.type, res.title,
              :parameters => overrides[:parameters],
              :file       => overrides[:file],
              :line       => overrides[:line],
              :source     => overrides[:source],
              :scope      => overrides[:scope])

        scope.compiler.add_override(newres)
      end
    end
  end

  # filter out object that this collector has previously found.
  objects.reject! { |o| @collected.include?(o.ref) }

  return false if objects.empty?

  # keep an eye on the resources we have collected
  objects.inject(@collected) { |c,o| c[o.ref]=o; c }

  # return our newly collected resources
  objects
end